quickstart
==========

Try these functions to get a feeling of what the package does

**Main**

Quick convenience

- :ref:`tprint`
- :ref:`is_list_like`
- :ref:`force_list`

**DS**

Quick ways to filter, score and split DataFrames

- :ref:`qf`
- :ref:`f_score`
- :ref:`k_split`
- :ref:`df_split`

**Modelling**

Modelling provides an extension on any statistical model that implements .fit and .predict that allows for easy multi
modelling.

- :ref:`Model`
- :ref:`Models`

**Plotting**

Animated plots and distribution plots

- :ref:`animplot`
- :ref:`distplot`
- :ref:`facet_wrap`
